==> vnpy_uft-3.7.2.4.1.tar.gz: vnpy_uft-3.7.2.4.1/vnpy_uft/api/generator/uft_td_header_function.h <==
int reqAuthenticate(const dict &req, int reqid);

int reqUserLogin(const dict &req, int reqid);

int reqUserPasswordUpdate(const dict &req, int reqid);

int reqOrderInsert(const dict &req, int reqid);

int reqOrderAction(const dict &req, int reqid);

int reqExerciseOrderInsert(const dict &req, int reqid);

int reqExerciseOrderAction(const dict &req, int reqid);

int reqLockInsert(const dict &req, int reqid);

int reqForQuoteInsert(const dict &req, int reqid);

int reqCombActionInsert(const dict &req, int reqid);

int reqQueryMaxOrderVolume(const dict &req, int reqid);

int reqQueryLockVolume(const dict &req, int reqid);

int reqQueryExerciseVolume(const dict &req, int reqid);

int reqQryPosition(const dict &req, int reqid);

int reqQryTradingAccount(const dict &req, int reqid);

int reqQryOrder(const dict &req, int reqid);

int reqQryTrade(const dict &req, int reqid);

int reqQryExercise(const dict &req, int reqid);

int reqQryLock(const dict &req, int reqid);

int reqQryCombAction(const dict &req, int reqid);

int reqQryPositionCombineDetail(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

int reqQryCoveredShort(const dict &req, int reqid);

int reqQryExerciseAssign(const dict &req, int reqid);

int reqTransfer(const dict &req, int reqid);

int reqQryTransfer(const dict &req, int reqid);

int reqQueryBankBalance(const dict &req, int reqid);

int reqQueryBankAccount(const dict &req, int reqid);

int reqQueryBillContent(const dict &req, int reqid);

int reqBillConfirm(const dict &req, int reqid);

int reqQryMargin(const dict &req, int reqid);

int reqQryCommission(const dict &req, int reqid);

int reqQryExchangeRate(const dict &req, int reqid);

int reqQryPositionDetail(const dict &req, int reqid);

int reqQrySysConfig(const dict &req, int reqid);

int reqQryDepthMarketData(const dict &req, int reqid);

==> vnpy_uft-3.7.2.4.2.tar.gz: vnpy_uft-3.7.2.4.2/vnpy_uft/api/generator/uft_td_header_function.h <==
int reqAuthenticate(const dict &req, int reqid);

int reqSubmitUserSystemInfo(const dict &req, int reqid);

int reqUserLogin(const dict &req, int reqid);

int reqUserPasswordUpdate(const dict &req, int reqid);

int reqOrderInsert(const dict &req, int reqid);

int reqOrderAction(const dict &req, int reqid);

int reqExerciseOrderInsert(const dict &req, int reqid);

int reqExerciseOrderAction(const dict &req, int reqid);

int reqLockInsert(const dict &req, int reqid);

int reqForQuoteInsert(const dict &req, int reqid);

int reqCombActionInsert(const dict &req, int reqid);

int reqQueryMaxOrderVolume(const dict &req, int reqid);

int reqQryLockVolume(const dict &req, int reqid);

int reqQueryExerciseVolume(const dict &req, int reqid);

int reqQryCombVolume(const dict &req, int reqid);

int reqQryPosition(const dict &req, int reqid);

int reqQryTradingAccount(const dict &req, int reqid);

int reqQryOrder(const dict &req, int reqid);

int reqQryTrade(const dict &req, int reqid);

int reqQryExercise(const dict &req, int reqid);

int reqQryLock(const dict &req, int reqid);

int reqQryCombAction(const dict &req, int reqid);

int reqQryPositionCombineDetail(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

int reqQryCoveredShort(const dict &req, int reqid);

int reqQryExerciseAssign(const dict &req, int reqid);

int reqTransfer(const dict &req, int reqid);

int reqQryTransfer(const dict &req, int reqid);

int reqQueryBankBalance(const dict &req, int reqid);

int reqQueryBankAccount(const dict &req, int reqid);

int reqMultiCentreFundTrans(const dict &req, int reqid);

int reqQueryBillContent(const dict &req, int reqid);

int reqBillConfirm(const dict &req, int reqid);

int reqQryMargin(const dict &req, int reqid);

int reqQryCommission(const dict &req, int reqid);

int reqQryExchangeRate(const dict &req, int reqid);

int reqQryPositionDetail(const dict &req, int reqid);

int reqQrySysConfig(const dict &req, int reqid);

int reqQryDepthMarketData(const dict &req, int reqid);

int reqFundTrans(const dict &req, int reqid);

int reqQryFundTrans(const dict &req, int reqid);

int reqQryClientNotice(const dict &req, int reqid);

int reqQryOptUnderly(const dict &req, int reqid);

int reqQrySecuDepthMarket(const dict &req, int reqid);

int reqQryHistOrder(const dict &req, int reqid);

int reqQryHistTrade(const dict &req, int reqid);
